@@ -4,7 +4,7 @@ from typing import TYPE_CHECKING, Any
 
 from dateutil.parser import isoparse
 
-from ..core import BaseDomain
+from ..core import BaseDomain, DomainIdentityMixin
 
 if TYPE_CHECKING:
     from ..actions import BoundAction
@@ -12,7 +12,7 @@ if TYPE_CHECKING:
     from .client import BoundFirewall
 
 
-class Firewall(BaseDomain):
+class Firewall(BaseDomain, DomainIdentityMixin):
     """Firewall Domain
 
     :param id: int
