@@ -4,7 +4,7 @@ from typing import TYPE_CHECKING, Any, Literal
 
 from dateutil.parser import isoparse
 
-from ..core import BaseDomain
+from ..core import BaseDomain, DomainIdentityMixin
 
 if TYPE_CHECKING:
     from ..actions import BoundAction
@@ -17,7 +17,7 @@ if TYPE_CHECKING:
     from .client import BoundLoadBalancer
 
 
-class LoadBalancer(BaseDomain):
+class LoadBalancer(BaseDomain, DomainIdentityMixin):
     """LoadBalancer Domain
 
     :param id: int
@@ -76,7 +76,7 @@ class LoadBalancer(BaseDomain):
         id: int,
         name: str | None = None,
         public_net: PublicNetwork | None = None,
-        private_net: PrivateNet | None = None,
+        private_net: list[PrivateNet] | None = None,
         location: BoundLocation | None = None,
         algorithm: LoadBalancerAlgorithm | None = None,
         services: list[LoadBalancerService] | None = None,
@@ -200,9 +200,9 @@ class LoadBalancerService(BaseDomain):
                 if self.health_check.http.response is not None:
                     health_check_http["response"] = self.health_check.http.response
                 if self.health_check.http.status_codes is not None:
-                    health_check_http[
-                        "status_codes"
-                    ] = self.health_check.http.status_codes
+                    health_check_http["status_codes"] = (
+                        self.health_check.http.status_codes
+                    )
                 if self.health_check.http.tls is not None:
                     health_check_http["tls"] = self.health_check.http.tls
 
