@@ -1,9 +1,17 @@
+from __future__ import annotations
+
+from typing import TYPE_CHECKING
+
 from dateutil.parser import isoparse
 
-from ..core.domain import BaseDomain
+from ..core import BaseDomain, DomainIdentityMixin
+
+if TYPE_CHECKING:
+    from ..actions import BoundAction
+    from .client import BoundPlacementGroup
 
 
-class PlacementGroup(BaseDomain):
+class PlacementGroup(BaseDomain, DomainIdentityMixin):
     """Placement Group Domain
 
     :param id: int
@@ -28,7 +36,13 @@ class PlacementGroup(BaseDomain):
     TYPE_SPREAD = "spread"
 
     def __init__(
-        self, id=None, name=None, labels=None, servers=None, type=None, created=None
+        self,
+        id: int | None = None,
+        name: str | None = None,
+        labels: dict[str, str] | None = None,
+        servers: list[int] | None = None,
+        type: str | None = None,
+        created: str | None = None,
     ):
         self.id = id
         self.name = name
@@ -51,8 +65,8 @@ class CreatePlacementGroupResponse(BaseDomain):
 
     def __init__(
         self,
-        placement_group,  # type: BoundPlacementGroup
-        action,  # type: BoundAction
+        placement_group: BoundPlacementGroup,
+        action: BoundAction | None,
     ):
         self.placement_group = placement_group
         self.action = action
