@@ -1,10 +1,10 @@
 from __future__ import annotations
 
-from typing import TYPE_CHECKING
+from typing import TYPE_CHECKING, Literal
 
 from dateutil.parser import isoparse
 
-from ..core import BaseDomain
+from ..core import BaseDomain, DomainIdentityMixin
 
 if TYPE_CHECKING:
     from ..actions import BoundAction
@@ -13,6 +13,7 @@ if TYPE_CHECKING:
     from ..floating_ips import BoundFloatingIP
     from ..images import BoundImage
     from ..isos import BoundIso
+    from ..metrics import Metrics
     from ..networks import BoundNetwork
     from ..placement_groups import BoundPlacementGroup
     from ..primary_ips import BoundPrimaryIP, PrimaryIP
@@ -21,7 +22,7 @@ if TYPE_CHECKING:
     from .client import BoundServer
 
 
-class Server(BaseDomain):
+class Server(BaseDomain, DomainIdentityMixin):
     """Server Domain
 
     :param id: int
@@ -244,6 +245,24 @@ class RequestConsoleResponse(BaseDomain):
         self.password = password
 
 
+class RebuildResponse(BaseDomain):
+    """Rebuild Response Domain
+
+    :param action: Shows the progress of the server rebuild action
+    :param root_password: The root password of the server when not using SSH keys
+    """
+
+    __slots__ = ("action", "root_password")
+
+    def __init__(
+        self,
+        action: BoundAction,
+        root_password: str | None,
+    ):
+        self.action = action
+        self.root_password = root_password
+
+
 class PublicNetwork(BaseDomain):
     """Public Network Domain
 
@@ -409,3 +428,25 @@ class ServerCreatePublicNetwork(BaseDomain):
         self.ipv6 = ipv6
         self.enable_ipv4 = enable_ipv4
         self.enable_ipv6 = enable_ipv6
+
+
+MetricsType = Literal[
+    "cpu",
+    "disk",
+    "network",
+]
+
+
+class GetMetricsResponse(BaseDomain):
+    """Get a Server Metrics Response Domain
+
+    :param metrics: The Server metrics
+    """
+
+    __slots__ = ("metrics",)
+
+    def __init__(
+        self,
+        metrics: Metrics,
+    ):
+        self.metrics = metrics
